#[repr(transparent)]pub struct Timing1(pub u32);Expand description
Timing1
Tuple Fields
0: u32Implementations
Sourceimpl Timing1
impl Timing1
Sourcepub const fn set_trelax(&mut self, val: u8)
pub const fn set_trelax(&mut self, val: u8)
CSB, PGENB and LOAD to STROBE setup and hold time
Sourcepub const fn tps(&self) -> u8
pub const fn tps(&self) -> u8
PS to CSB setup and hold time between power switch and chip select assertion
Sourcepub const fn set_tps(&mut self, val: u8)
pub const fn set_tps(&mut self, val: u8)
PS to CSB setup and hold time between power switch and chip select assertion